[![status - under developement](https://img.shields.io/badge/status-under_developement-yellow)](https://github.com/johangroe/)
# wetteronline-api
An unofficial API for the german weatherforecast service wetteronline.de
